==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/domain/resource/dto/resource/MapLog.java <==
package cn.gtmap.gtc.resource.domain.resource.dto.resource;

/**
 * @Author:张帅杰2019/11/22 16:24
 * PS:上图日志检索支持
 */
public class MapLog {
    /**
     * 数据源
    **/
    private String dataSource;
    /**
     * 图层名称
     **/
    private String layerName;
    /**
     * 项目名称
     **/
    private String projectName;
    /**
     * 操作事件
     * 可选 sde-insert    sde-update    sde-deltete
     **/
    private String events;
    /**
     * 开始时间戳
     **/
    private Long start;
    /**
     * 结束时间戳
     **/
    private Long end;
    /**
     * 操作状态，正常为true，异常为false
     **/
    private boolean status;
    /**
     * 图层字段及值，可多值
     **/
    private String kv;
    /**
     * 分页，第几页
     **/
    private Integer page;
    /**
     * 分页，页面大小
     **/
    private Integer size;

    public String getDataSource() {
        return dataSource;
    }

    public void setDataSource(String dataSource) {
        this.dataSource = dataSource;
    }

    public String getLayerName() {
        return layerName;
    }

    public void setLayerName(String layerName) {
        this.layerName = layerName;
    }

    public String getEvents() {
        return events;
    }

    public void setEvents(String events) {
        this.events = events;
    }

    public Long getStart() {
        return start;
    }

    public void setStart(Long start) {
        this.start = start;
    }

    public Long getEnd() {
        return end;
    }

    public void setEnd(Long end) {
        this.end = end;
    }

    public boolean isStatus() {
        return status;
    }

    public void setStatus(boolean status) {
        this.status = status;
    }

    public String getKv() {
        return kv;
    }

    public void setKv(String kv) {
        this.kv = kv;
    }

    public Integer getPage() {
        return page;
    }

    public void setPage(Integer page) {
        this.page = page;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/domain/resource/dto/resource/MapLog.java <==
package cn.gtmap.gtc.resource.domain.resource.dto.resource;

/**
 * @Author:张帅杰2019/11/22 16:24
 * PS:上图日志检索支持
 */
public class MapLog {
    /**
     * 数据源
    **/
    private String dataSource;
    /**
     * 图层名称
     **/
    private String layerName;
    /**
     * 项目名称
     **/
    private String projectName;
    /**
     * 操作事件
     * 可选 sde-insert    sde-update    sde-deltete
     **/
    private String events;
    /**
     * 开始时间戳
     **/
    private Long start;
    /**
     * 结束时间戳
     **/
    private Long end;
    /**
     * 操作状态，正常为true，异常为false
     **/
    private boolean status;
    /**
     * 图层字段及值，可多值
     **/
    private String kv;
    /**
     * 分页，第几页
     **/
    private Integer page;
    /**
     * 分页，页面大小
     **/
    private Integer size;

    private String sortType;

    public String getDataSource() {
        return dataSource;
    }

    public void setDataSource(String dataSource) {
        this.dataSource = dataSource;
    }

    public String getLayerName() {
        return layerName;
    }

    public void setLayerName(String layerName) {
        this.layerName = layerName;
    }

    public String getEvents() {
        return events;
    }

    public void setEvents(String events) {
        this.events = events;
    }

    public Long getStart() {
        return start;
    }

    public void setStart(Long start) {
        this.start = start;
    }

    public Long getEnd() {
        return end;
    }

    public void setEnd(Long end) {
        this.end = end;
    }

    public boolean isStatus() {
        return status;
    }

    public void setStatus(boolean status) {
        this.status = status;
    }

    public String getKv() {
        return kv;
    }

    public void setKv(String kv) {
        this.kv = kv;
    }

    public Integer getPage() {
        return page;
    }

    public void setPage(Integer page) {
        this.page = page;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSortType() {
        return sortType;
    }

    public void setSortType(String sortType) {
        this.sortType = sortType;
    }
}
